@@ -1,6 +1,6 @@
 /*
 
-   Copyright 2021, dettus@dettus.net
+   Copyright 2022, dettus@dettus.net
 
    Redistribution and use in source and binary forms, with or without modification,
    are permitted provided that the following conditions are met:
@@ -139,7 +139,8 @@ int loader_dsk_amstradcpc_mag(unsigned char* magbuf,int* magsize,
 		unsigned char* diskimage,int diskcnt,
 		unsigned char* tmpbuf,int tmpbufsize,
 		int gamedetected,
-		tDirEntry* pDirEntries,int entrycnt,int sectorsize)
+		tDirEntry* pDirEntries,int entrycnt,int sectorsize,
+		int nodoc)
 {
 	int outputidx;
 	int version;
@@ -148,7 +149,6 @@ int loader_dsk_amstradcpc_mag(unsigned char* magbuf,int* magsize,
 	int string1size;
 	int string2size;
 	int dictsize;
-	int huffmantreeidx;
 
 	outputidx=42;
 	version=loader_dsk_knownGames[gamedetected].version;
@@ -190,36 +190,26 @@ int loader_dsk_amstradcpc_mag(unsigned char* magbuf,int* magsize,
 	dictsize=loader_dsk_readfile(diskimage,&magbuf[outputidx],FILESUFFIX8,pDirEntries,entrycnt,sectorsize);
 	loader_dsk_descrambler(&magbuf[outputidx],dictsize,0x1803);	// the dictionary is scrambled the same way the code is
 	outputidx+=dictsize;
-	huffmantreeidx=string1size;
-	if (string1size>0x10000)
+	if (nodoc)
 	{
-		int x;
-		x=string1size+string2size;
-		string1size=0x10000;
-		string2size=x-string1size;
+		int i;
+		unsigned char* ptr=(unsigned char*)&magbuf[0];
+		for (i=0;i<outputidx-4;i++)
+		{
+			if (ptr[i+0]==0x62 && ptr[i+1]==0x02 && ptr[i+2]==0xa2 && ptr[i+3]==0x00) {ptr[i+0]=0x4e;ptr[i+1]=0x71;}
+			if (ptr[i+0]==0xa4 && ptr[i+1]==0x06 && ptr[i+2]==0xaa && ptr[i+3]==0xdf) {ptr[i+0]=0x4e;ptr[i+1]=0x71;}
+		}
 	}
 
-	magbuf[0]='M';magbuf[1]='a';magbuf[2]='S';magbuf[3]='c';        //  0.. 3: the magic word
-	WRITE_INT32BE(magbuf, 4 ,outputidx);                               //  4.. 7: the total size
-	WRITE_INT32BE(magbuf, 8 ,42);                           //  8..11: the size of the header
-	WRITE_INT16BE(magbuf,12 ,version);  // 12..13: the version for the virtual machine
-	WRITE_INT32BE(magbuf,14 ,code1size+code2size);          // 14..17 the size of the game code
-	WRITE_INT32BE(magbuf,18 ,string1size);                  // 18..21 the size of the string1
-	WRITE_INT32BE(magbuf,22 ,string2size);                  // 22..25 the size of the string2
-	WRITE_INT32BE(magbuf,26 ,dictsize);                     // 26..29 the size of the dictionary
-	WRITE_INT32BE(magbuf,30 ,huffmantreeidx)                // 30..33 the beginning of the huffman tree within the string buffer
-	WRITE_INT32BE(magbuf,34 ,0);                            //  34..37: undo size
-	WRITE_INT32BE(magbuf,38 ,0);                            //  38..41: undo pc
-
 	*magsize=outputidx;
-
-	return 0;
+	return loader_common_addmagheader(magbuf,outputidx,version,code1size+code2size,string1size,string2size,dictsize,-1);
 }
 int loader_dsk_spectrum_mag(unsigned char* magbuf,int* magsize,
 		unsigned char* diskimage,int diskcnt,
 		unsigned char* tmpbuf,int tmpbufsize,
 		int gamedetected,
-		tDirEntry* pDirEntries,int entrycnt,int sectorsize)
+		tDirEntry* pDirEntries,int entrycnt,int sectorsize,
+		int nodoc)
 {
 	int codesize;
 	int string1size;
@@ -247,6 +237,16 @@ int loader_dsk_spectrum_mag(unsigned char* magbuf,int* magsize,
 	outputidx+=dictsize;
 	
 	version=loader_dsk_knownGames[gamedetected].version;
+	if (nodoc)
+	{
+		int i;
+		unsigned char* ptr=(unsigned char*)&magbuf[0];
+		for (i=0;i<outputidx-4;i++)
+		{
+			if (ptr[i+0]==0x62 && ptr[i+1]==0x02 && ptr[i+2]==0xa2 && ptr[i+3]==0x00) {ptr[i+0]=0x4e;ptr[i+1]=0x71;}
+			if (ptr[i+0]==0xa4 && ptr[i+1]==0x06 && ptr[i+2]==0xaa && ptr[i+3]==0xdf) {ptr[i+0]=0x4e;ptr[i+1]=0x71;}
+		}
+	}
 	if (version==3 && magbuf[0x2836]==0x66) magbuf[0x2836]=0x60;	// final patch for myth
 	*magsize=outputidx;
 
@@ -332,7 +332,8 @@ int loader_dsk_amstradcpc_gfx(
 int loader_dsk(char* amstradcpcname,
 		char *magbuf,int* magsize,
 		char* gfxbuf,int* gfxsize,
-		int amstrad0spectrum1)
+		int amstrad0spectrum1,
+		int nodoc)
 {
 	char* filename[MAX_DISKS];
 	unsigned char *dskimage;
@@ -690,7 +691,8 @@ int loader_dsk(char* amstradcpcname,
 				dskimage,diskcnt,
 				(unsigned char*)gfxbuf,2*DSK_IMAGESIZE,
 				gamedetected,
-				dirEntries,entrycnt,sectorsize);
+				dirEntries,entrycnt,sectorsize,
+				nodoc);
 
 
 		*gfxsize=0;
@@ -700,7 +702,8 @@ int loader_dsk(char* amstradcpcname,
 				dskimage,diskcnt,
 				(unsigned char*)gfxbuf,2*DSK_IMAGESIZE,
 				gamedetected,
-				dirEntries,entrycnt,sectorsize);
+				dirEntries,entrycnt,sectorsize,
+				nodoc);
 		if (retval) return retval;
 
 		retval=loader_dsk_amstradcpc_gfx((unsigned char*)gfxbuf,gfxsize,
