@@ -1,6 +1,6 @@
 /*
 
-Copyright 2021, dettus@dettus.net
+Copyright 2022, dettus@dettus.net
 
 Redistribution and use in source and binary forms, with or without modification,
 are permitted provided that the following conditions are met:
@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 int loader_dsk(char* amstradcpcname,
 		char *magbuf,int* magsize,
 		char* gfxbuf,int* gfxsize,
-		int amstrad0spectrum1);
+		int amstrad0spectrum1,
+		int nodoc);
 
 #endif
